%This is a script to make the Arbic et al. 2022 figures
% dependencies:
% you will need the jLab data analysis package for Matlab written by J.M.
% Lilly available at http://www.jmlilly.net/software.html
% and the cmocean colormaps available at http://matplotlib.org/cmocean
% and the scripts mycolormap.m, shaddyerror.m, lefttitle.m, coats.m,
% f2phi.m

% Add paths for jlab routines:
addpath /huron/archive/umich/matlab/jlab
jlab_addpath

% Add path for cmocean:
addpath /huron/archive/umich/matlab/cmocean


%% some needed configuration
set(0,'defaultTextInterpreter','latex')
set(0,'defaultLegendInterpreter','latex')
set(0,'defaultTextFontName','times')

% change the following to your path to repository:
path_to_repo = '../'; 
%path_to_repo = '/nfs/huron/archive/umich/papers/paper_brasch_elipot_MITgcmvsHYCOM_drifters/REPOSITORY/TEST_ELIPOT_PLOTTING_CODE_REVISION/';


%% load results from repo

% drifter KE map results
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/drifters_lowf_ke.mat']);
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/drifters_diurnal_ke.mat']);
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/drifters_semidiurnal_ke.mat']);
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/drifters_inertial_ke.mat']);
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/drifters_semidiurnal_wide_ke.mat']);
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/drifters_semidiurnal_wider_ke.mat']);
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/drifters_semidiurnal_widest_ke.mat']);
% globally averaged spectra for drifters;
load([path_to_repo 'DRIFTERS_RESULTS_AND_README/globalaveragedspectra_104.mat']);

% HYCOM results
dat2 = load([path_to_repo 'HYCOM_ANALYSISCODE_RESULTS_AND_README/HYCOM_binaverages_onedegreegrid.mat']);
use dat2.IntegralQuantities_BinAverages_HYCOM
load([path_to_repo 'HYCOM_ANALYSISCODE_RESULTS_AND_README/HYCOM_binaverages_onedegreegrid_fullspectra.mat']);

% MITgcm LLC4320 results
dat3 = load([path_to_repo 'MITgcm_ANALYSISCODE_RESULTS_AND_README/MITgcm_binaverages_onedegreegrid.mat']);
use dat3.IntegralQuantities_BinAverages_MITgcm
load([path_to_repo 'MITgcm_ANALYSISCODE_RESULTS_AND_README/binavg_MITgcm_fullspectra_onto_onedeg_grid.mat']);

% dat3 = load("/Volumes/GoogleDrive-100185530479395605261/My Drive/tidaldrift/brasch/drifters_new_results/Corrected_MITgcm_results_17June2022/MITgcm_binaverages_onedegreegrid.mat");
% use dat3.IntegralQuantities_BinAverages_MITgcm
% load("/Volumes/GoogleDrive-100185530479395605261/My Drive/tidaldrift/brasch/drifters_new_results/Corrected_MITgcm_results_17June2022/binavg_MITgcm_fullspectra_onto_onedeg_grid.mat");

%% Calculate globally-averaged spectra for model results for Figure 3
qs = 1:60; % southern latitudes
qn = 61:120; % northern latitudes
ff = sort(fourier(1/24,1440,'two'));
qpos = 720:1440; % ff is the frequency scale for the HYCOM results. % positive frequencies
qneg = [1440 1:720]; % negative frequencies and Nyquist repeated

% add a weighting; first calculate area of bins
xedges = [0:1:360];
yedges = [-60:1:60];
A = (2*pi*radearth^2/360)*abs(sind(yedges(1:end-1)') - sind(yedges(2:1:end)'))*abs(xedges(1:end-1)-xedges(2:end));
% need to divide by the sum of valid locations, not the complete total
q = isfinite(sum(HYCOM_0m_fullspectra_binavg,3));
W = A/sum(A(q));

% calculate weighted averages for HYCOM
% calculate area-weighted and non area-weighted versions
y = bsxfun(@times,W,HYCOM_0m_fullspectra_binavg);
x = cat(1,y(qs,:,qpos),flip(y(qn,:,qneg),3)); % select southern (northern) latitudes and positive (negative) frequencies, i.e. anticyclonic
msac_0_h = (squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

y = bsxfun(@times,W,HYCOM_0m_fullspectra_binavg);
x = cat(1,y(qs,:,qneg),flip(y(qn,:,qpos),3)); % select southern (northern) latitudes and negative (positive) frequencies, i.e. cyclonic
msc_0_h = flip(squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

y = bsxfun(@times,W,HYCOM_15m_fullspectra_binavg);
x = cat(1,y(qs,:,qpos),flip(y(qn,:,qneg),3));
msac_15_h = (squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

y = bsxfun(@times,W,HYCOM_15m_fullspectra_binavg);
x = cat(1,y(qs,:,qneg),flip(y(qn,:,qpos),3));
msc_15_h = flip(squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

% MITgcm
y = bsxfun(@times,W,MITgcm_0m_fullspectra_binavg);
x = cat(1,y(qs,:,qpos),flip(y(qn,:,qneg),3));
msac_0_m = (squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

y = bsxfun(@times,W,MITgcm_0m_fullspectra_binavg);
x = cat(1,y(qs,:,qneg),flip(y(qn,:,qpos),3));
msc_0_m = flip(squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

y = bsxfun(@times,W,MITgcm_15m_fullspectra_binavg);
x = cat(1,y(qs,:,qpos),flip(y(qn,:,qneg),3));
msac_15_m = (squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

y = bsxfun(@times,W,MITgcm_15m_fullspectra_binavg);
x = cat(1,y(qs,:,qneg),flip(y(qn,:,qpos),3));
msc_15_m = flip(squeeze(sum(sum(x,1,'omitnan'),2,'omitnan')));

%% load tidal frequencies
fid1 = fopen('tidal_info.txt','r');
ft = textscan(fid1,'%s %f %f\n','headerlines',2);
fclose(fid1);

%% Make Figure 3
% undrogued, drogued, 0m MITgcm, 15m MITgcm, 0m HYCOM, 15m HYCOM
% define a color scheme/scale
cc = [[0 0 0];[0.5 0.5 0.5];[230 159 0]./255;[0.95 0.81 0.5];[86 180 233]./255;[0.67 0.85 0.96]];

figure,
g1= axes;hold on,
g1.XLim = 12*[-1 1];
g1.YLim = [-7 1];
ht = vlines([ft{3} ; -ft{3}]);
set(ht,'color',0.75*[1 1 1],'linestyle','-');
h1 = plot(f/2/pi,log10(msac_u_w),'color',cc(1,:),'LineWidth',1);
h2 = plot(-f/2/pi,log10(msc_u_w),'color',cc(1,:),'LineWidth',1);
h3 = plot(f/2/pi,log10(msac_d_w),'color',cc(2,:));
h4 = plot(-f/2/pi,log10(msc_d_w),'color',cc(2,:));

h5 = plot(f/2/pi,log10(msac_0_h),'color',cc(5,:),'LineWidth',1);
h6 = plot(-f/2/pi,log10(msc_0_h),'color',cc(5,:),'LineWidth',1);
h7 = plot(f/2/pi,log10(msac_15_h),'color',cc(6,:));
h8 = plot(-f/2/pi,log10(msc_15_h),'color',cc(6,:));

h9 = plot(f/2/pi,log10(msac_0_m),'color',cc(3,:),'LineWidth',1);
h10 = plot(-f/2/pi,log10(msc_0_m),'color',cc(3,:),'LineWidth',1);
h11 = plot(f/2/pi,log10(msac_15_m),'color',cc(4,:));
h12 = plot(-f/2/pi,log10(msc_15_m),'color',cc(4,:));

g1.XTick = [-12:2:12];
g1.YTick = [-7:1:1];
g1.YLabel.String = 'PSD (log$_{10}$ m$^2$ s$^{-2}$ cpd$^{-1}$)';
g1.Box = 'on';
hl = legend([h1 h3 h5 h7 h9 h11],{'Undrogued','Drogued','HYCOM (0m)','HYCOM (15m)',...
    'MITgcm (0m)','MITgcm (15m)'},'location','south');
g1.XLabel.String = 'Frequency (cpd)';

% plot main diurnal and semi-diurnal species
%S2 M2 O1 K1
%56 47 12 20
% 2 1.93 0.92 1.00
g2= axes;hold on,
g2.XLim = [0.5 2.5];
g2.YLim = [-4 -1];
g2.XTick = [1 2];
g2.YTick = [-4:1:-1];
ht = vlines(ft{3}([56 47 12 20]),'k:');

h1 = plot(f/2/pi,log10(msac_u_w),'color',cc(1,:),'LineWidth',1);
h3 = plot(f/2/pi,log10(msac_d_w),'color',cc(2,:));
h5 = plot(f/2/pi,log10(msac_0_h),'color',cc(5,:),'LineWidth',1);
h7 = plot(f/2/pi,log10(msac_15_h),'color',cc(6,:));
h9 = plot(f/2/pi,log10(msac_0_m),'color',cc(3,:),'LineWidth',1);
h11 = plot(f/2/pi,log10(msac_15_m),'color',cc(4,:));
g2.Position = [0.65 0.65 0.25 0.25];
g2.Box = 'on';
ht2 = text(g2,[0.7 1.1 1.7 2.1],[1 1 1 1]*-3.8,{'O1','K1','M2','S2'});

g3= axes;hold on,
g3.XLim = [-2.5 -0.5];
g3.YLim = [-4 -1];
g3.XTick = [-2 -1];
g3.YTick = [-4:1:-1];
ht = vlines(-ft{3}([56 47 12 20]),'k:');
h2 = plot(-f/2/pi,log10(msc_u_w),'color',cc(1,:),'LineWidth',1);
h4 = plot(-f/2/pi,log10(msc_d_w),'color',cc(2,:));
h6 = plot(-f/2/pi,log10(msc_0_h),'color',cc(5,:),'LineWidth',1);
h8 = plot(-f/2/pi,log10(msc_15_h),'color',cc(6,:));
h10 = plot(-f/2/pi,log10(msc_0_m),'color',cc(3,:),'LineWidth',1);
h12 = plot(-f/2/pi,log10(msc_15_m),'color',cc(4,:));
g3.Position = [0.16 0.65 0.25 0.25];
g3.Box = 'on';
ht3 = text(g3,[-0.7 -1.1 -1.7 -2.1]-0.1,[1 1 1 1]*-1.2,{'O1','K1','M2','S2'});

%% define ratio function
rf = @(x) x./(1+x);
% its derivative:
drf = @(x) 1./((1+x).^2);

% define colorscales
cm1 = cmocean('thermal');
cm2 = (mycolormap(64,2));

%% low-frequency KE maps, Figure 4

clear g
figure,
for k = 1:9
    g(k) = subplot(3,3,k);
end

% drifter undrogued
use drifters_lowf_ke.drifters_lowf_u
foo1 = sum(abs(mz).^2,3)+covz(:,:,1)+covz(:,:,2,2);
k = 1;
axes(g(k));
jpcolor(xmid,ymid,log10(foo1));
caxis(g(k),[-2 0])
colormap(g(k),cm1);
coasts;

% drifter drogued
use drifters_lowf_ke.drifters_lowf_d
foo2 = sum(abs(mz).^2,3)+covz(:,:,1)+covz(:,:,2,2);
k = 4;
axes(g(k));
jpcolor(xmid,ymid,log10(foo2));
caxis(g(k),[-2 0])
colormap(g(k),cm1);
coasts;

% drifter undrogued/drogued
k = 7;
axes(g(k));
x = (foo1)./(foo2);
jpcolor(xmid,ymid,rf(x));
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% HYCOM 0 m
k = 2;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_0m_lowf_binavg).');
caxis(g(k),[-2 0])
colormap(g(k),cm1);
coasts;

% HYCOM 15 m
k = 5;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_15m_lowf_binavg).');
caxis(g(k),[-2 0])
colormap(g(k),cm1);
coasts;

% HYCOM 0/15
k = 8;
axes(g(k));
x = (HYCOM_0m_lowf_binavg./HYCOM_15m_lowf_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,rf(x).');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% MITgcm 0 m
k = 3;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_0m_lowf_binavg).');
caxis(g(k),[-2 0])
colormap(g(k),cm1);
coasts;

% MITgcm 15 m
k = 6;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_15m_lowf_binavg).');
caxis(g(k),[-2 0])
colormap(g(k),cm1);
coasts;

% MITgcm 0/15
k = 9;
axes(g(k));
x = (MITgcm_0m_lowf_binavg./MITgcm_15m_lowf_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,rf(x).');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

for k = 1:9
    g(k).XLim = [0 360];
    g(k).YLim = 60*[-1 1];
    g(k).XTick = [0:90:360];
    g(k).YTick = [-60:30:60];
    g(k).TickDir = 'out';
end
packfig(3,3);

g(1).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(4).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(7).YTickLabel = {'60^\circS','30^\circS','0^\circ','30^\circN','60^\circN'};

g(7).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(8).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(9).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW','0^\circ'};

hc3 = colorbar(g(3),'location','EastOutside');
dum = hc3.Position;
hc3.Position = dum +  [0.065 0.025 0 -0.05];
hc3.Ticks = [-2 -1 0];
hc3.TickLabels = {'10^{-2}','10^{-1}','10^{0}'};
hc3.Label.String = 'm^2 s^{-2}';

hc6 = colorbar(g(6),'location','EastOutside');
dum = hc6.Position;
hc6.Position = dum + [0.065 0.025 0 -0.05];
hc6.Ticks = [-2 -1 0];
hc6.TickLabels = {'10^{-2}','10^{-1}','10^{0}'};
hc6.Label.String = 'm^2 s^{-2}';

hc9 = colorbar(g(9),'location','EastOutside');
dum = hc9.Position;
hc9.Position = dum +  [0.065 0.025 0 -0.05];
hc9.Ticks = [0 .5 1];
hc9.TickLabels = {'0','0.5','1'};
hc9.Label.String = '';

g(1).Title.String = 'Drifters';
g(2).Title.String = 'HYCOM';
g(3).Title.String = 'MITgcm';

% labels
texte = {'(a) Undrogued','(b) 0m','(c) 0m','(d) Drogued',...
    '(e) 15m','(f) 15m','(g) U./(U.+D.)',...
    '(h) 0m/(0m+15m)','(i) 0m/(0m+15m)'};
clear ht
for k = 1:9
    ht(k) = text(g(k),5,50,texte{k});
    ht(k).BackgroundColor = 'w';
    ht(k).EdgeColor = 'k';
    ht(k).FontSize = 8;
end

% calculate and display spatial correlation of fields
% Considering fields 1 to 9
% rounded to 2 digits R = 10^2;
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = vcolon(log10(foo1(ia,:)));
y = vcolon(log10(HYCOM_0m_lowf_binavg).');
z = vcolon(log10(MITgcm_0m_lowf_binavg).');
q = isfinite(x) & isfinite(y);
rho12 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho13 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho23 = round(corr(y(q),z(q)),2);

x = vcolon(log10(foo2(ia,:)));
y = vcolon(log10(HYCOM_15m_lowf_binavg).');
z = vcolon(log10(MITgcm_15m_lowf_binavg).');
q = isfinite(x) & isfinite(y);
rho45 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho46 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho56 = round(corr(y(q),z(q)),2);

x = vcolon(rf(foo1(ia,:)./foo2(ia,:)));
y = vcolon(rf(HYCOM_0m_lowf_binavg./HYCOM_15m_lowf_binavg).');
z = vcolon(rf(MITgcm_0m_lowf_binavg./MITgcm_15m_lowf_binavg).');
q = isfinite(x) & isfinite(y);
rho78 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho79 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho89 = round(corr(y(q),z(q)),2);

clear hc
xt = 15;yt = 30;

k = 1;hc(k,1) = text(g(k),xt,yt,num2str(rho12,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho13,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 2;hc(k,1) = text(g(k),xt,yt,num2str(rho23,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 4;hc(k,1) = text(g(k),xt,yt,num2str(rho45,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho46,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 5;hc(k,1) = text(g(k),xt,yt,num2str(rho56,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 7;hc(k,1) = text(g(k),xt,yt,num2str(rho78,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho79,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 8;hc(k,1) = text(g(k),xt,yt,num2str(rho89,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);


%% Near-inertial KE map, Figure 6

cm1 = cmocean('thermal');
cm2 = mycolormap(64,2);
ca = [-3 -1];

clear g
figure,
for k = 1:9
    g(k) = subplot(3,3,k);
end

% drifter undrogued
use drifters_inertial_ke.drifters_inertial_u
foo1 = covz(:,:,1,1)+covz(:,:,2,2);
foo1(abs(ymid)<4.33,:) = NaN;
k = 1;
axes(g(k));
jpcolor(xmid,ymid,log10(foo1));
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% drifter drogued
use drifters_inertial_ke.drifters_inertial_d
foo2 = covz(:,:,1,1)+covz(:,:,2,2);
foo2(abs(ymid)<4.33,:) = NaN;
k = 4;
axes(g(k));
jpcolor(xmid,ymid,log10(foo2));
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% drifter undrogued/drogued
k = 7;
axes(g(k));
x = foo1./foo2;
jpcolor(xmid,ymid,rf(x));
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% HYCOM 0 m
k = 2;
axes(g(k));
x = HYCOM_0m_nearinertial_binavg;
q = abs(targetgrid_lats)<4.33;x(:,q) = NaN;
jpcolor(targetgrid_lons,targetgrid_lats,log10(x).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% HYCOM 15 m
k = 5;
axes(g(k));
x = HYCOM_15m_nearinertial_binavg;
q = abs(targetgrid_lats)<4.33;x(:,q) = NaN;
jpcolor(targetgrid_lons,targetgrid_lats,log10(x).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% HYCOM 0/15
k = 8;
axes(g(k));
x = (HYCOM_0m_nearinertial_binavg./HYCOM_15m_nearinertial_binavg);
q = abs(targetgrid_lats)<4.33;x(:,q) = NaN;
jpcolor(targetgrid_lons,targetgrid_lats,rf(x).');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% MITgcm 0 m
k = 3;
axes(g(k));
x = MITgcm_0m_nearinertial_binavg;
q = abs(targetgrid_lats)<4.33;x(:,q) = NaN;
jpcolor(targetgrid_lons,targetgrid_lats,log10(x).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 15 m
k = 6;
axes(g(k));
x = MITgcm_15m_nearinertial_binavg;
q = abs(targetgrid_lats)<4.33;x(:,q) = NaN;
jpcolor(targetgrid_lons,targetgrid_lats,log10(x).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 0/15
k = 9;
axes(g(k));
x = (MITgcm_0m_nearinertial_binavg./MITgcm_15m_nearinertial_binavg);
q = abs(targetgrid_lats)<4.33;x(:,q) = NaN;
jpcolor(targetgrid_lons,targetgrid_lats,rf(x).');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

for k = 1:9
    g(k).XLim = [0 360];
    g(k).YLim = 60*[-1 1];
    g(k).XTick = [0:90:360];
    g(k).YTick = [-60:30:60];
    g(k).TickDir = 'out';
end
packfig(3,3);

g(1).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(4).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(7).YTickLabel = {'60^\circS','30^\circS','0^\circ','30^\circN','60^\circN'};

g(7).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(8).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(9).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW','0^\circ'};

hc3 = colorbar(g(3),'location','EastOutside');
dum = hc3.Position;
hc3.Position = dum +  [0.065 0.025 0 -0.05];
hc3.Ticks = [-3:1:-1];
hc3.TickLabels = {'10^{-3}','10^{-2}','10^{-1}'};
hc3.Label.String = 'm^2 s^{-2}';

hc6 = colorbar(g(6),'location','EastOutside');
dum = hc6.Position;
hc6.Position = dum + [0.065 0.025 0 -0.05];
hc6.Ticks = [-3:1:-1];
hc6.TickLabels = {'10^{-3}','10^{-2}','10^{-1}'};
hc6.Label.String = 'm^2 s^{-2}';

hc9 = colorbar(g(9),'location','EastOutside');
dum = hc9.Position;
hc9.Position = dum +  [0.065 0.025 0 -0.05];
hc9.Ticks = [0 0.5 1];
hc9.TickLabels = {'0','0.5','1'};
hc9.Label.String = '';

g(1).Title.String = 'Drifters';
g(2).Title.String = 'HYCOM';
g(3).Title.String = 'MITgcm';

% labels
texte = {'(a) Undrogued','(b) 0m','(c) 0m','(d) Drogued',...
    '(e) 15m','(f) 15m','(g) U./(U.+D.)',...
    '(h) 0m/(0m+15m)','(i) 0m/(0m+15m)'};
clear ht
for k = 1:9
    ht(k) = text(g(k),5,50,texte{k});
    ht(k).BackgroundColor = 'w';
    ht(k).EdgeColor = 'k';
    ht(k).FontSize = 8;
end

% calculate and display spatial correlation of fields
% Considering fields 1 to 9
% rounded to 2 digits
qlat = abs(targetgrid_lats)<4.33;
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = log10(foo1(ia,:));x(q,:) = NaN;x = vcolon(x);
y = (log10(HYCOM_0m_nearinertial_binavg).');y(q,:) = NaN;y = vcolon(y);
z = (log10(MITgcm_0m_nearinertial_binavg).');z(q,:) = NaN;z = vcolon(z);
q = isfinite(x) & isfinite(y);
rho12 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho13 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho23 = round(corr(y(q),z(q)),2);

x = log10(foo2(ia,:));x(q,:) = NaN;x = vcolon(x);
y = (log10(HYCOM_15m_nearinertial_binavg).');y(q,:) = NaN;y = vcolon(y);
z = (log10(MITgcm_15m_nearinertial_binavg).');z(q,:) = NaN;z = vcolon(z);
q = isfinite(x) & isfinite(y);
rho45 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho46 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho56 = round(corr(y(q),z(q)),2);

x = (rf(foo1(ia,:)./foo2(ia,:)));x(qlat,:) = NaN;x = vcolon(x);
y = vcolon(rf(HYCOM_0m_nearinertial_binavg./HYCOM_15m_nearinertial_binavg).');
z = vcolon(rf(MITgcm_0m_nearinertial_binavg./MITgcm_15m_nearinertial_binavg).');
q = isfinite(x) & isfinite(y);
rho78 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho79 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho89 = round(corr(y(q),z(q)),2);

clear hc
xt = 15;yt = 30;

k = 1;hc(k,1) = text(g(k),xt,yt,num2str(rho12,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho13,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 2;hc(k,1) = text(g(k),xt,yt,num2str(rho23,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 4;hc(k,1) = text(g(k),xt,yt,num2str(rho45,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho46,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 5;hc(k,1) = text(g(k),xt,yt,num2str(rho56,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 7;hc(k,1) = text(g(k),xt,yt,num2str(rho78,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho79,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 8;hc(k,1) = text(g(k),xt,yt,num2str(rho89,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

%% Diurnal KE map, Figure 9

cm1 = cmocean('thermal');
cm2 = mycolormap(64,2);
ca = [-4 -1];

clear g
figure,
for k = 1:9
    g(k) = subplot(3,3,k);
end

% drifter undrogued
use drifters_diurnal_ke.drifters_diurnal_u
foo1 = covz(:,:,1,1)+covz(:,:,2,2);
k = 1;
axes(g(k));
jpcolor(xmid,ymid,log10(foo1));
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% drifter drogued
use drifters_diurnal_ke.drifters_diurnal_d
foo2 = covz(:,:,1,1)+covz(:,:,2,2);
k = 4;
axes(g(k));
jpcolor(xmid,ymid,log10(foo2));
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% drifter undrogued/drogued
k = 7;
axes(g(k));
x = foo1./foo2;
jpcolor(xmid,ymid,rf(x));
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% HYCOM 0 m
k = 2;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_0m_diurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% HYCOM 15 m
k = 5;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_15m_diurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% HYCOM 0/15
k = 8;
axes(g(k));
x = (HYCOM_0m_diurnal_binavg./HYCOM_15m_diurnal_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,rf(x).');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% MITgcm 0 m
k = 3;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_0m_diurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 15 m
k = 6;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_15m_diurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 0/15
k = 9;
axes(g(k));
x = (MITgcm_0m_diurnal_binavg./MITgcm_15m_diurnal_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,rf(x).');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

for k = 1:9
    g(k).XLim = [0 360];
    g(k).YLim = 60*[-1 1];
    g(k).XTick = [0:90:360];
    g(k).YTick = [-60:30:60];
    g(k).TickDir = 'out';
end
packfig(3,3);

g(1).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(4).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(7).YTickLabel = {'60^\circS','30^\circS','0^\circ','30^\circN','60^\circN'};

g(7).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(8).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(9).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW','0^\circ'};

hc3 = colorbar(g(3),'location','EastOutside');
dum = hc3.Position;
hc3.Position = dum +  [0.065 0.025 0 -0.05];
hc3.Ticks = [-4:1:-1];
hc3.TickLabels = {'10^{-4}','10^{-3}','10^{-2}','10^{-1}'};
hc3.Label.String = 'm^2 s^{-2}';

hc6 = colorbar(g(6),'location','EastOutside');
dum = hc6.Position;
hc6.Position = dum + [0.065 0.025 0 -0.05];
hc6.Ticks = [-4:1:-1];
hc6.TickLabels = {'10^{-4}','10^{-3}','10^{-2}','10^{-1}'};
hc6.Label.String = 'm^2 s^{-2}';

hc9 = colorbar(g(9),'location','EastOutside');
dum = hc9.Position;
hc9.Position = dum +  [0.065 0.025 0 -0.05];
hc9.Ticks = [0 0.5 1];
hc9.TickLabels = {'0','0.5','1'};
hc9.Label.String = '';

g(1).Title.String = 'Drifters';
g(2).Title.String = 'HYCOM';
g(3).Title.String = 'MITgcm';

% labels
texte = {'(a) Undrogued','(b) 0m','(c) 0m','(d) Drogued',...
    '(e) 15m','(f) 15m','(g) U./(U.+D.)',...
    '(h) 0m/(0m+15m)','(i) 0m/(0m+15m)'};
clear ht
for k = 1:9
    ht(k) = text(g(k),5,50,texte{k});
    ht(k).BackgroundColor = 'w';
    ht(k).EdgeColor = 'k';
    ht(k).FontSize = 8;
end

% calculate and display spatial correlation of fields
% Considering fields 1 to 9
% rounded to 2 digits
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = vcolon(log10((foo1(ia,:))));
y = vcolon(log10(HYCOM_0m_diurnal_binavg).');
z = vcolon(log10(MITgcm_0m_diurnal_binavg).');
q = isfinite(x) & isfinite(y);
rho12 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho13 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho23 = round(corr(y(q),z(q)),2);

x = vcolon(log10((foo2(ia,:))));
y = vcolon(log10(HYCOM_15m_diurnal_binavg).');
z = vcolon(log10(MITgcm_15m_diurnal_binavg).');
q = isfinite(x) & isfinite(y);
rho45 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho46 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho56 = round(corr(y(q),z(q)),2);

x = vcolon(rf((foo1(ia,:))./(foo2(ia,:))));
y = vcolon(rf(HYCOM_0m_diurnal_binavg./HYCOM_15m_diurnal_binavg).');
z = vcolon(rf(MITgcm_0m_diurnal_binavg./MITgcm_15m_diurnal_binavg).');
q = isfinite(x) & isfinite(y);
rho78 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho79 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho89 = round(corr(y(q),z(q)),2);

clear hc
xt = 15;yt = 30;

k = 1;hc(k,1) = text(g(k),xt,yt,num2str(rho12,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho13,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 2;hc(k,1) = text(g(k),xt,yt,num2str(rho23,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 4;hc(k,1) = text(g(k),xt,yt,num2str(rho45,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho46,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 5;hc(k,1) = text(g(k),xt,yt,num2str(rho56,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 7;hc(k,1) = text(g(k),xt,yt,num2str(rho78,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho79,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 8;hc(k,1) = text(g(k),xt,yt,num2str(rho89,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

%% Diurnal KE map from  harmonic analysis map, Figure 10

cm1 = cmocean('thermal');
cm2 = mycolormap(64,2);
ca = [-4 -1];

clear g
figure,
for k = 1:6
    g(k) = subplot(3,2,k);
end

% HYCOM 0 m
k = 1;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_0m_diurnal_harmonicanalysis_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% HYCOM 15 m
k = 3;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_15m_diurnal_harmonicanalysis_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% HYCOM 0/15
k = 5;
axes(g(k));
x = rf(HYCOM_0m_diurnal_harmonicanalysis_binavg./HYCOM_15m_diurnal_harmonicanalysis_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,x.');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% MITgcm 0 m
k = 2;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_0m_diurnal_harmonicanalysis_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 15 m
k = 4;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_15m_diurnal_harmonicanalysis_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 0/15
k = 6;
axes(g(k));
x = rf(MITgcm_0m_diurnal_harmonicanalysis_binavg./MITgcm_15m_diurnal_harmonicanalysis_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,x.');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

for k = 1:6
    g(k).XLim = [0 360];
    g(k).YLim = 60*[-1 1];
    g(k).XTick = [0:90:360];
    g(k).YTick = [-60:30:60];
    g(k).TickDir = 'out';
end
packfig(3,2);

g(1).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(3).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(5).YTickLabel = {'60^\circS','30^\circS','0^\circ','30^\circN','60^\circN'};

g(5).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(6).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW','0^\circ'};

pause(2);

hc2 = colorbar(g(2),'location','EastOutside');
dum = hc2.Position;
hc2.Position = dum +  [0.055 0.025 0 -0.05];
hc2.Ticks = [-4:1:-1];
hc2.TickLabels = {'10^{-4}','10^{-3}','10^{-2}','10^{-1}'};
hc2.Label.String = 'm^2 s^{-2}';

hc4 = colorbar(g(4),'location','EastOutside');
dum = hc4.Position;
hc4.Position = dum + [0.055 0.025 0 -0.05];
hc4.Ticks = [-4:1:-1];
hc4.TickLabels = {'10^{-4}','10^{-3}','10^{-2}','10^{-1}'};
hc4.Label.String = 'm^2 s^{-2}';

hc6 = colorbar(g(6),'location','EastOutside');
dum = hc6.Position;
hc6.Position = dum +  [0.055 0.025 0 -0.05];
hc6.Ticks = [0 0.5 1];
hc6.TickLabels = {'0','0.5','1'};
hc6.Label.String = '';

g(1).Title.String = 'HYCOM';
g(2).Title.String = 'MITgcm';

% labels
texte = {'(a) 0m','(b) 0m',...
    '(c) 15m','(d) 15m',...
    '(e) 0m/(0m+15m)','(f) 0m/(0m+15m)'};
clear ht
for k = 1:6
    ht(k) = text(g(k),5,50,texte{k});
    ht(k).BackgroundColor = 'w';
    ht(k).EdgeColor = 'k';
    ht(k).FontSize = 8;
end

% calculate and display spatial correlation of fields
% Considering fields 1 to 6
% rounded to 2 digits
y = vcolon(log10(HYCOM_0m_diurnal_harmonicanalysis_binavg).');
z = vcolon(log10(MITgcm_0m_diurnal_harmonicanalysis_binavg).');
q = isfinite(y) & isfinite(z);
rho12 = round(corr(y(q),z(q)),2);

y = vcolon(log10(HYCOM_15m_diurnal_harmonicanalysis_binavg).');
z = vcolon(log10(MITgcm_15m_diurnal_harmonicanalysis_binavg).');
q = isfinite(y) & isfinite(z);
rho34 = round(corr(y(q),z(q)),2);

y = vcolon(rf(HYCOM_0m_diurnal_harmonicanalysis_binavg./HYCOM_15m_diurnal_harmonicanalysis_binavg));
z = vcolon(rf(MITgcm_0m_diurnal_harmonicanalysis_binavg./MITgcm_15m_diurnal_harmonicanalysis_binavg));
q = isfinite(y) & isfinite(z);
rho56 = round(corr(y(q),z(q)),2);

clear hc
xt = 15;yt = 30;
k = 1;hc(k,1) = text(g(k),xt,yt,num2str(rho12,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 3;hc(k,1) = text(g(k),xt,yt,num2str(rho34,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 5;hc(k,1) = text(g(k),xt,yt,num2str(rho56,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

%% Semidiurnal KE map, Figure 12

cm1 = cmocean('thermal');
cm2 = mycolormap(64,2);
ca = [-4 -1];

clear g
figure,
for k = 1:9
    g(k) = subplot(3,3,k);
end

% drifter undrogued
use drifters_semidiurnal_ke.drifters_semidiurnal_u
foo1 = covz(:,:,1,1)+covz(:,:,2,2);
k = 1;
axes(g(k));
jpcolor(xmid,ymid,log10(foo1));
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% drifter drogued
use drifters_semidiurnal_ke.drifters_semidiurnal_d
foo2 = covz(:,:,1,1)+covz(:,:,2,2);
k = 4;
axes(g(k));
jpcolor(xmid,ymid,log10(foo2));
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% drifter undrogued/drogued
k = 7;
axes(g(k));
x = foo1./foo2;
jpcolor(xmid,ymid,rf(x));
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% HYCOM 0 m
k = 2;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_0m_semidiurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;
% draw circle around instability in NP in HYCOM
g(k).NextPlot = 'add';
x0 = 197;y0 = 43;
r = 20;
th = 0:pi/50:2*pi;
xunit = r*cos(th(:)) + x0;
yunit = r*sin(th(:)) + y0;
hh = plot(g(k),xunit, yunit,'k:','linewidth',1);

% HYCOM 15 m
k = 5;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(HYCOM_15m_semidiurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;
% draw circle around instability in NP in HYCOM
g(k).NextPlot = 'add';
x0 = 197;y0 = 43;
r = 20;
th = 0:pi/50:2*pi;
xunit = r*cos(th(:)) + x0;
yunit = r*sin(th(:)) + y0;
hh = plot(g(k),xunit, yunit,'k:','linewidth',1);

% HYCOM 0/15
k = 8;
axes(g(k));
x = rf(HYCOM_0m_semidiurnal_binavg./HYCOM_15m_semidiurnal_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,x.');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

% MITgcm 0 m
k = 3;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_0m_semidiurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 15 m
k = 6;
axes(g(k));
jpcolor(targetgrid_lons,targetgrid_lats,log10(MITgcm_15m_semidiurnal_binavg).');
caxis(g(k),ca)
colormap(g(k),cm1);
coasts;

% MITgcm 0/15
k = 9;
axes(g(k));
x = rf(MITgcm_0m_semidiurnal_binavg./MITgcm_15m_semidiurnal_binavg);
jpcolor(targetgrid_lons,targetgrid_lats,x.');
caxis(g(k),[0 1])
colormap(g(k),cm2);
coasts;

for k = 1:9
    g(k).XLim = [0 360];
    g(k).YLim = 60*[-1 1];
    g(k).XTick = [0:90:360];
    g(k).YTick = [-60:30:60];
    g(k).TickDir = 'out';
end
packfig(3,3);

g(1).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(4).YTickLabel = {'','30^\circS','0^\circ','30^\circN','60^\circN'};
g(7).YTickLabel = {'60^\circS','30^\circS','0^\circ','30^\circN','60^\circN'};

g(7).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(8).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW',''};
g(9).XTickLabel = {'0^\circ','90^\circE','180^\circE','90^\circW','0^\circ'};

hc3 = colorbar(g(3),'location','EastOutside');
dum = hc3.Position;
hc3.Position = dum +  [0.065 0.025 0 -0.05];
hc3.Ticks = [-4:1:-1];
hc3.TickLabels = {'10^{-4}','10^{-3}','10^{-2}','10^{-1}'};
hc3.Label.String = 'm^2 s^{-2}';

hc6 = colorbar(g(6),'location','EastOutside');
dum = hc6.Position;
hc6.Position = dum + [0.065 0.025 0 -0.05];
hc6.Ticks = [-4:1:-1];
hc6.TickLabels = {'10^{-4}','10^{-3}','10^{-2}','10^{-1}'};
hc6.Label.String = 'm^2 s^{-2}';

hc9 = colorbar(g(9),'location','EastOutside');
dum = hc9.Position;
hc9.Position = dum +  [0.065 0.025 0 -0.05];
hc9.Ticks = [0 0.5 1];
hc9.TickLabels = {'0','0.5','1'};
hc9.Label.String = '';

g(1).Title.String = 'Drifters';
g(2).Title.String = 'HYCOM';
g(3).Title.String = 'MITgcm';

% labels
texte = {'(a) Undrogued','(b) 0m','(c) 0m','(d) Drogued',...
    '(e) 15m','(f) 15m','(g) U./(U.+D.)',...
    '(h) 0m/(0m+15m)','(i) 0m/(0m+15m)'};
clear ht
for k = 1:9
    ht(k) = text(g(k),5,50,texte{k});
    ht(k).BackgroundColor = 'w';
    ht(k).EdgeColor = 'k';
    ht(k).FontSize = 8;
end

% calculate and display spatial correlation of fields
% Considering fields 1 to 9
% rounded to 2 digits
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = vcolon(log10((foo1(ia,:))));
y = vcolon(log10(HYCOM_0m_semidiurnal_binavg).');
z = vcolon(log10(MITgcm_0m_semidiurnal_binavg).');
q = isfinite(x) & isfinite(y);
rho12 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho13 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho23 = round(corr(y(q),z(q)),2);

x = vcolon(log10((foo2(ia,:))));
y = vcolon(log10(HYCOM_15m_semidiurnal_binavg).');
z = vcolon(log10(MITgcm_15m_semidiurnal_binavg).');
q = isfinite(x) & isfinite(y);
rho45 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho46 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho56 = round(corr(y(q),z(q)),2);

x = vcolon(rf((foo1(ia,:))./(foo2(ia,:))));
y = vcolon(rf(HYCOM_0m_semidiurnal_binavg./HYCOM_15m_semidiurnal_binavg).');
z = vcolon(rf(MITgcm_0m_semidiurnal_binavg./MITgcm_15m_semidiurnal_binavg).');
q = isfinite(x) & isfinite(y);
rho78 = round(corr(x(q),y(q)),2);
q = isfinite(x) & isfinite(z);
rho79 = round(corr(x(q),z(q)),2);
q = isfinite(y) & isfinite(z);
rho89 = round(corr(y(q),z(q)),2);

clear hc
xt = 15;yt = 30;

k = 1;hc(k,1) = text(g(k),xt,yt,num2str(rho12,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho13,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 2;hc(k,1) = text(g(k),xt,yt,num2str(rho23,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 4;hc(k,1) = text(g(k),xt,yt,num2str(rho45,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho46,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 5;hc(k,1) = text(g(k),xt,yt,num2str(rho56,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

k = 7;hc(k,1) = text(g(k),xt,yt,num2str(rho78,'%.2f'),'Color',cc(5,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
hc(k,2) = text(g(k),xt+50,yt,num2str(rho79,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);
k = 8;hc(k,1) = text(g(k),xt,yt,num2str(rho89,'%.2f'),'Color',cc(3,:),'BackgroundColor','w','EdgeColor','k','Fontsize',8);

%% Calculate zonal averages from KE maps
% select the drifter bins were the model data are non NaNs
% this  eliminate the shallow bins for drifters

% low frequency results
% undrogued drifters
use drifters_lowf_ke.drifters_lowf_u
x = sum(abs(mz).^2,3)+covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_0m_lowf_binavg.';
z = MITgcm_0m_lowf_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.lowf_u  = mean(x,2,'omitnan');
eke_lat.lowf_sem_u = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% drogued
use drifters_lowf_ke.drifters_lowf_d
x = sum(abs(mz).^2,3)+covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_15m_lowf_binavg.';
z = MITgcm_15m_lowf_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.lowf_d  = mean(x,2,'omitnan');
eke_lat.lowf_sem_d = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% lowfreq band, HYCOM 0m
x = HYCOM_0m_lowf_binavg.';
eke_lat.lowf_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.lowf_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% lowfreq band, HYCOM 15m
x = HYCOM_15m_lowf_binavg.';
eke_lat.lowf_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.lowf_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% lowfreq band, MITgcm 0m
x = MITgcm_0m_lowf_binavg.';
eke_lat.lowf_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.lowf_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% lowfreq band, MITgcm 15m
x = MITgcm_15m_lowf_binavg.';
eke_lat.lowf_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.lowf_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

% inertial band, undrogued drifters
use drifters_inertial_ke.drifters_inertial_u
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_0m_nearinertial_binavg.';
z = MITgcm_0m_nearinertial_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
x(abs(targetgrid_lats)<4.33,:) = NaN;
eke_lat.nearinertial_u  = mean(x,2,'omitnan');
eke_lat.nearinertial_sem_u = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% inertial band, drogued drifters
use drifters_inertial_ke.drifters_inertial_d
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_15m_nearinertial_binavg.';
z = MITgcm_15m_nearinertial_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
x(abs(targetgrid_lats)<4.33,:) = NaN;
eke_lat.nearinertial_d  = mean(x,2,'omitnan');
eke_lat.nearinertial_sem_d = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% inertial band, HYCOM 0m
x = HYCOM_0m_nearinertial_binavg.';
eke_lat.nearinertial_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.nearinertial_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% inertial band, HYCOM 15m
x = HYCOM_15m_nearinertial_binavg.';
eke_lat.nearinertial_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.nearinertial_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% inertial band, MITgcm 0m
x = MITgcm_0m_nearinertial_binavg.';
eke_lat.nearinertial_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.nearinertial_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% inertial band, MITgcm 15m
x = MITgcm_15m_nearinertial_binavg.';
eke_lat.nearinertial_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.nearinertial_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

% inertial bands, separating the Pacific (lon : ) and Atlantic (lon: ) Basins north of 10N.
% for drifters
% pacific q = 100:261 if lat>=96
% q = 100:263 if lat >= 93 ansd < 96
% q = 100:276 if lat >=87 & < 93
% q = 100:284 if lat >=80
eke_lat.nearinertial_u_pac = NaN*eke_lat.nearinertial_u;
eke_lat.nearinertial_u_atl = NaN*eke_lat.nearinertial_u;
eke_lat.nearinertial_sem_u_pac = NaN*eke_lat.nearinertial_sem_u;
eke_lat.nearinertial_sem_u_atl = NaN*eke_lat.nearinertial_sem_u;

eke_lat.nearinertial_d_pac = NaN*eke_lat.nearinertial_d;
eke_lat.nearinertial_d_atl = NaN*eke_lat.nearinertial_d;
eke_lat.nearinertial_sem_d_pac = NaN*eke_lat.nearinertial_sem_d;
eke_lat.nearinertial_sem_d_atl = NaN*eke_lat.nearinertial_sem_d;

% calculate only for northern hemisphere
% for k = 65 (4.5N) to 120 (60N)
% eastern limits of pacific 100 264 273 278 283

use drifters_inertial_ke.drifters_inertial_u
x1 = covz(:,:,1,1)+covz(:,:,2,2);
y1 = HYCOM_0m_nearinertial_binavg.';
z1 = MITgcm_0m_nearinertial_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x1 = x1(ia,:);
q = isnan(y1)|isnan(z1);
x1(q) = NaN;

use drifters_inertial_ke.drifters_inertial_d
x2 = covz(:,:,1,1)+covz(:,:,2,2);
y2 = HYCOM_15m_nearinertial_binavg.';
z2 = MITgcm_15m_nearinertial_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x2 = x2(ia,:);
q = isnan(y2)|isnan(z2);
x2(q) = NaN;

for k = 65:120
    if k>=65 && k<69
        mm1 = 100:283;
        mm2 = 283:360;
    elseif k>=69 && k<77
        mm1 = 100:278;
        mm2 = 278:360;
    elseif k>=77 && k<80
        mm1 = 100:273;
        mm2 = 273:360;
    elseif k>=80
        mm1 = 100:264;
        mm2 = 264:360;
    end
    
    eke_lat.nearinertial_u_pac(k)  = mean(x1(k,mm1),2,'omitnan');
    eke_lat.nearinertial_sem_u_pac(k) = std(x1(k,mm1),0,2,'omitnan')./sum(isfinite(x1(k,mm1)),2,'omitnan').^0.5;
    
    eke_lat.nearinertial_u_atl(k)  = mean(x1(k,mm2),2,'omitnan');
    eke_lat.nearinertial_sem_u_atl(k) = std(x1(k,mm2),0,2,'omitnan')./sum(isfinite(x1(k,mm2)),2,'omitnan').^0.5;
    
    eke_lat.nearinertial_d_pac(k)  = mean(x2(k,mm1),2,'omitnan');
    eke_lat.nearinertial_sem_d_pac(k) = std(x2(k,mm1),0,2,'omitnan')./sum(isfinite(x2(k,mm1)),2,'omitnan').^0.5;
    
    eke_lat.nearinertial_d_atl(k)  = mean(x2(k,mm2),2,'omitnan');
    eke_lat.nearinertial_sem_d_atl(k) = std(x2(k,mm2),0,2,'omitnan')./sum(isfinite(x2(k,mm2)),2,'omitnan').^0.5;
    
end

% inertial band, HYCOM 0m Pacific, Atlantic
% inertial band, HYCOM 15m Pacific, Atlantic
eke_lat.nearinertial_0m_HYCOM_pac = NaN*eke_lat.nearinertial_0m_HYCOM;
eke_lat.nearinertial_sem_0m_HYCOM_pac = NaN*eke_lat.nearinertial_sem_0m_HYCOM;
eke_lat.nearinertial_15m_HYCOM_pac = NaN*eke_lat.nearinertial_15m_HYCOM;
eke_lat.nearinertial_sem_15m_HYCOM_pac = NaN*eke_lat.nearinertial_sem_15m_HYCOM;
eke_lat.nearinertial_0m_HYCOM_atl = NaN*eke_lat.nearinertial_0m_HYCOM;
eke_lat.nearinertial_sem_0m_HYCOM_atl = NaN*eke_lat.nearinertial_sem_0m_HYCOM;
eke_lat.nearinertial_15m_HYCOM_atl = NaN*eke_lat.nearinertial_15m_HYCOM;
eke_lat.nearinertial_sem_15m_HYCOM_atl = NaN*eke_lat.nearinertial_sem_15m_HYCOM;

% inertial band, MITgcm 0m Pacific, Atlantic
% inertial band, MITgcm 15m Pacific, Atlantic
eke_lat.nearinertial_0m_MITgcm_pac = NaN*eke_lat.nearinertial_0m_MITgcm;
eke_lat.nearinertial_sem_0m_MITgcm_pac = NaN*eke_lat.nearinertial_sem_0m_MITgcm;
eke_lat.nearinertial_15m_MITgcm_pac = NaN*eke_lat.nearinertial_15m_MITgcm;
eke_lat.nearinertial_sem_15m_MITgcm_pac = NaN*eke_lat.nearinertial_sem_15m_MITgcm;
eke_lat.nearinertial_0m_MITgcm_atl = NaN*eke_lat.nearinertial_0m_MITgcm;
eke_lat.nearinertial_sem_0m_MITgcm_atl = NaN*eke_lat.nearinertial_sem_0m_MITgcm;
eke_lat.nearinertial_15m_MITgcm_atl = NaN*eke_lat.nearinertial_15m_MITgcm;
eke_lat.nearinertial_sem_15m_MITgcm_atl = NaN*eke_lat.nearinertial_sem_15m_MITgcm;

x = HYCOM_0m_nearinertial_binavg.';
y = HYCOM_15m_nearinertial_binavg.';

for k = 1:120
    if k >=60 && k<69 % 100?:283
        m = 283;
        eke_lat.nearinertial_0m_HYCOM_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_HYCOM_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_HYCOM_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_HYCOM_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    elseif k>=69 && k<76 % 100:277
        m = 277;
        eke_lat.nearinertial_0m_HYCOM_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_HYCOM_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_HYCOM_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_HYCOM_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    elseif k>=76 && k<79 % 100:272
        m = 272;
        eke_lat.nearinertial_0m_HYCOM_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_HYCOM_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_HYCOM_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_HYCOM_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    elseif k>=79 % 100:263
        m = 263;
        eke_lat.nearinertial_0m_HYCOM_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_HYCOM_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_HYCOM_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_HYCOM_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_HYCOM_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_HYCOM_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    end
end

x = MITgcm_0m_nearinertial_binavg.';
y = MITgcm_15m_nearinertial_binavg.';

for k = 1:120
    if k >=60 && k<69 % 100?:283
        m = 283;
        eke_lat.nearinertial_0m_MITgcm_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_MITgcm_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_MITgcm_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_MITgcm_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    elseif k>=69 && k<76 % 100:277
        m = 277;
        eke_lat.nearinertial_0m_MITgcm_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_MITgcm_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_MITgcm_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_MITgcm_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    elseif k>=76 && k<79 % 100:272
        m = 272;
        eke_lat.nearinertial_0m_MITgcm_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_MITgcm_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_MITgcm_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_MITgcm_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    elseif k>=79 % 100:263
        m = 263;
        eke_lat.nearinertial_0m_MITgcm_pac(k) = mean(x(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_pac(k) = std(x(k,100:m),0,2,'omitnan')./sum(isfinite(x(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_0m_MITgcm_atl(k) = mean(x(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_0m_MITgcm_atl(k) = std(x(k,m:end),0,2,'omitnan')./sum(isfinite(x(k,m:end)),2,'omitnan').^0.5;
        
        eke_lat.nearinertial_15m_MITgcm_pac(k) = mean(y(k,100:m),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_pac(k) = std(y(k,100:m),0,2,'omitnan')./sum(isfinite(y(k,100:m)),2,'omitnan').^0.5;
        eke_lat.nearinertial_15m_MITgcm_atl(k) = mean(y(k,m:end),2,'omitnan');
        eke_lat.nearinertial_sem_15m_MITgcm_atl(k) = std(y(k,m:end),0,2,'omitnan')./sum(isfinite(y(k,m:end)),2,'omitnan').^0.5;
        
    end
end

% diurnal band, undrogued drifters
use drifters_diurnal_ke.drifters_diurnal_u
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_0m_diurnal_binavg.';
z = MITgcm_0m_diurnal_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.diurnal_u  = mean(x,2,'omitnan');
eke_lat.diurnal_sem_u = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% diurnal band, drogued drifters
use drifters_diurnal_ke.drifters_diurnal_d
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_15m_diurnal_binavg.';
z = MITgcm_15m_diurnal_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.diurnal_d  = mean(x,2,'omitnan');
eke_lat.diurnal_sem_d = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
%eke_lat.diurnal_sem_d = std(mz7(:,:,1),0,2,'omitnan')./sum(isfinite(mz7(:,:,1)),2,'omitnan').^0.5;
% diurnal band, HYCOM 0m
x = HYCOM_0m_diurnal_binavg.';
eke_lat.diurnal_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.diurnal_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% diurnal band, HYCOM 15m
x = HYCOM_15m_diurnal_binavg.';
eke_lat.diurnal_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.diurnal_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% diurnal band, MITgcm 0m
x = MITgcm_0m_diurnal_binavg.';
eke_lat.diurnal_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.diurnal_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% diurnal band, MITgcm 15m
x = MITgcm_15m_diurnal_binavg.';
eke_lat.diurnal_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.diurnal_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

if 1
    % diurnal band, harmonicanalysis, HYCOM 0m
    x = HYCOM_0m_diurnal_harmonicanalysis_binavg.';
    eke_lat.diurnal_harmonicanalysis_0m_HYCOM = mean(x,2,'omitnan');
    eke_lat.diurnal_harmonicanalysis_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
    % diurnal band, HYCOM 15m
    x = HYCOM_15m_diurnal_harmonicanalysis_binavg.';
    eke_lat.diurnal_harmonicanalysis_15m_HYCOM = mean(x,2,'omitnan');
    eke_lat.diurnal_harmonicanalysis_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
    % diurnal band, MITgcm 0m
    x = MITgcm_0m_diurnal_harmonicanalysis_binavg.';
    eke_lat.diurnal_harmonicanalysis_0m_MITgcm = mean(x,2,'omitnan');
    eke_lat.diurnal_harmonicanalysis_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
    % diurnal band, MITgcm 15m
    x = MITgcm_15m_diurnal_harmonicanalysis_binavg.';
    eke_lat.diurnal_harmonicanalysis_15m_MITgcm = mean(x,2,'omitnan');
    eke_lat.diurnal_harmonicanalysis_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
end

% semidiurnal band, undrogued drifters
use drifters_semidiurnal_ke.drifters_semidiurnal_u
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_0m_semidiurnal_binavg.';
z = MITgcm_0m_semidiurnal_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_u  = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_u = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% semidiurnal band, drogued drifters
use drifters_semidiurnal_ke.drifters_semidiurnal_d
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_15m_semidiurnal_binavg.';
z = MITgcm_15m_semidiurnal_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_d  = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_d = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
%eke_lat.semidiurnal_sem_d = std(mz7(:,:,2),0,2,'omitnan')./sum(isfinite(mz7(:,:,2)),2,'omitnan').^0.5;
% semidiurnal band, HYCOM 0m
x = HYCOM_0m_semidiurnal_binavg.';
eke_lat.semidiurnal_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% semidiurnal band, HYCOM 15m
x = HYCOM_15m_semidiurnal_binavg.';
eke_lat.semidiurnal_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% semidiurnal band, MITgcm 0m
x = MITgcm_0m_semidiurnal_binavg.';
eke_lat.semidiurnal_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% semidiurnal band, MITgcm 15m
x = MITgcm_15m_semidiurnal_binavg.';
eke_lat.semidiurnal_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;


%WIDE
use drifters_semidiurnal_wide_ke.drifters_semidiurnal_wide_u
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_0m_semidiurnal_wide_binavg.';
z = MITgcm_0m_semidiurnal_wide_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_wide_u  = mean(x,2,'omitnan');
eke_lat.semidiurnal_wide_sem_u = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% semidiurnal band, drogued drifters
use drifters_semidiurnal_wide_ke.drifters_semidiurnal_wide_d
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_15m_semidiurnal_wide_binavg.';
z = MITgcm_15m_semidiurnal_wide_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_wide_d  = mean(x,2,'omitnan');
eke_lat.semidiurnal_wide_sem_d = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

%WIDER
use drifters_semidiurnal_wider_ke.drifters_semidiurnal_wider_u
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_0m_semidiurnal_wider_binavg.';
z = MITgcm_0m_semidiurnal_wider_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_wider_u  = mean(x,2,'omitnan');
eke_lat.semidiurnal_wider_sem_u = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% semidiurnal band, drogued drifters
use drifters_semidiurnal_wider_ke.drifters_semidiurnal_wider_d
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_15m_semidiurnal_wider_binavg.';
z = MITgcm_15m_semidiurnal_wider_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_wider_d  = mean(x,2,'omitnan');
eke_lat.semidiurnal_wider_sem_d = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

%WIDEST
use drifters_semidiurnal_widest_ke.drifters_semidiurnal_widest_u
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_0m_semidiurnal_widest_binavg.';
z = MITgcm_0m_semidiurnal_widest_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_widest_u  = mean(x,2,'omitnan');
eke_lat.semidiurnal_widest_sem_u = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;
% semidiurnal band, drogued drifters
use drifters_semidiurnal_widest_ke.drifters_semidiurnal_widest_d
x = covz(:,:,1,1)+covz(:,:,2,2);
y = HYCOM_15m_semidiurnal_widest_binavg.';
z = MITgcm_15m_semidiurnal_widest_binavg.';
[lia,ia,ib] = intersect(ymid,targetgrid_lats,'stable');
x = x(ia,:);
q = isnan(y)|isnan(z);
x(q) = NaN;
eke_lat.semidiurnal_widest_d  = mean(x,2,'omitnan');
eke_lat.semidiurnal_widest_sem_d = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

% semidiurnal band, HYCOM 0m
x = HYCOM_0m_semidiurnal_binavg.';
eke_lat.semidiurnal_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = HYCOM_0m_semidiurnal_wide_binavg.';
eke_lat.semidiurnal_wide_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_wide_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = HYCOM_0m_semidiurnal_wider_binavg.';
eke_lat.semidiurnal_wider_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_wider_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = HYCOM_0m_semidiurnal_widest_binavg.';
eke_lat.semidiurnal_widest_0m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_widest_sem_0m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

% semidiurnal band, HYCOM 15m
x = HYCOM_15m_semidiurnal_binavg.';
eke_lat.semidiurnal_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = HYCOM_15m_semidiurnal_wide_binavg.';
eke_lat.semidiurnal_wide_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_wide_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = HYCOM_15m_semidiurnal_wider_binavg.';
eke_lat.semidiurnal_wider_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_wider_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = HYCOM_15m_semidiurnal_widest_binavg.';
eke_lat.semidiurnal_widest_15m_HYCOM = mean(x,2,'omitnan');
eke_lat.semidiurnal_widest_sem_15m_HYCOM = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

% semidiurnal band, MITgcm 0m
x = MITgcm_0m_semidiurnal_binavg.';
eke_lat.semidiurnal_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = MITgcm_0m_semidiurnal_wide_binavg.';
eke_lat.semidiurnal_wide_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_wide_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = MITgcm_0m_semidiurnal_wider_binavg.';
eke_lat.semidiurnal_wider_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_wider_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = MITgcm_0m_semidiurnal_widest_binavg.';
eke_lat.semidiurnal_widest_0m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_widest_sem_0m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

% semidiurnal band, MITgcm 15m
x = MITgcm_15m_semidiurnal_binavg.';
eke_lat.semidiurnal_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = MITgcm_15m_semidiurnal_wide_binavg.';
eke_lat.semidiurnal_wide_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_wide_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = MITgcm_15m_semidiurnal_wider_binavg.';
eke_lat.semidiurnal_wider_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_wider_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

x = MITgcm_15m_semidiurnal_widest_binavg.';
eke_lat.semidiurnal_widest_15m_MITgcm = mean(x,2,'omitnan');
eke_lat.semidiurnal_widest_sem_15m_MITgcm = std(x,0,2,'omitnan')./sum(isfinite(x),2,'omitnan').^0.5;

%% Figures of zonal averages
% undrogued, drogued, 0m MITgcm, 15m MITgcm, 0m HYCOM, 15m HYCOM
cc = [[0 0 0];[0.5 0.5 0.5];[230 159 0]./255;[0.95 0.81 0.5];[86 180 233]./255;[0.67 0.85 0.96]];

% figure of lowfreq zonal averages, Figure 5
fac = 2;
clear ga
figure,
ga(1) = subplot(3,1,1);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.lowf_u,fac*eke_lat.lowf_sem_u,cc(1,:));
[h2,~] = shadyerror(targetgrid_lats,eke_lat.lowf_0m_MITgcm,fac*eke_lat.lowf_sem_0m_MITgcm,cc(3,:));
[h3,~] = shadyerror(targetgrid_lats,eke_lat.lowf_0m_HYCOM,fac*eke_lat.lowf_sem_0m_HYCOM,cc(5,:));
hl1 = legend(ga(1),[h1(1) h3(1) h2(1)],{'Undrogued','HYCOM (0m)','MITgcm (0m)'},'location','northwest','autoupdate','off');
% at what latitude is 0.9 f equal to 0.5 cpd 0.9 phi2f(x) = 0.5 -> f2phi(0.5/0.9);
%f2phi(0.5/0.9) = 16.08;
h1(1).Clipping = 'off';

ga(2) = subplot(3,1,2);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.lowf_d,fac*eke_lat.lowf_sem_d,cc(1,:));
[h2,~] = shadyerror(targetgrid_lats,eke_lat.lowf_15m_MITgcm,fac*eke_lat.lowf_sem_15m_MITgcm,cc(3,:));
[h3,~] = shadyerror(targetgrid_lats,eke_lat.lowf_15m_HYCOM,fac*eke_lat.lowf_sem_15m_HYCOM,cc(5,:));
hl2 = legend(ga(2),[h1(1) h3(1) h2(1)],{'Drogued','HYCOM (15m)','MITgcm (15m)'},'location','northwest','autoupdate','off');

ga(3) = subplot(3,1,3);hold on;
x = eke_lat.lowf_u; y = eke_lat.lowf_d;
dx =  eke_lat.lowf_sem_u;dy =  eke_lat.lowf_sem_d;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h1,~] = shadyerror(ymid(ia),z,fac*z_se,cc(1,:));
x = eke_lat.lowf_0m_MITgcm; y = eke_lat.lowf_15m_MITgcm;
dx =  eke_lat.lowf_sem_0m_MITgcm;dy =  eke_lat.lowf_sem_15m_MITgcm;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h2,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(3,:));
x = eke_lat.lowf_0m_HYCOM; y = eke_lat.lowf_15m_HYCOM;
dx =  eke_lat.lowf_sem_0m_HYCOM;dy =  eke_lat.lowf_sem_15m_HYCOM;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h3,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(5,:));
hl2 = legend(ga(3),[h1(1) h3(1) h2(1)],{'Drifters','HYCOM','MITgcm'},'location','north',...
    'orientation','horizon','autoupdate','off');

ga(1).XLim = 60*[-1 1];
ga(2).XLim = 60*[-1 1];
ga(3).XLim = 60*[-1 1];
ga(1).YLim = [0 0.4];
ga(2).YLim = [0 0.4];
ga(3).YLim = [0.4 .8];
for k = 1:3;ga(k).Box = 'on';end
for k = 1:2;ga(k).YLabel.String = 'm$^2$ s$^{-2}$';end
ga(3).YLabel.String = '';

ga(3).YTick = [0:0.1:1];
ga(1).YTick = [0:0.1:0.4];
ga(2).YTick = [0:0.1:0.4];

for k = 1:3;ga(k).XGrid = 'on';end
for k = 1:3;ga(k).YGrid = 'on';end

ht1 = lefttitle(ga(1),'(a) Undrogued/0m');
ht2 = lefttitle(ga(2),'(b) Drogued/15m');
ht3 = lefttitle(ga(3),'(c) 0m/(0m+15m)');

for k = 1:3
    ga(k).XTick = [-60:15:60];
    ga(k).TickDir = 'out';
end

ga(1).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(2).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(3).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};

clear hp
for k = 1:2
    hp(k) = patch(ga(k),f2phi(0.5/0.9)*[-1 1 1 -1 -1]',[0 0 0.4 0.4 0]',0.85*[1 1 1]);
    hp(k).FaceAlpha = 0.35;
    hp(k).EdgeColor = 'none';
end
k = 3;
hp(k) = patch(ga(k),f2phi(0.5/0.9)*[-1 1 1 -1 -1]',[0 0 1 1 0]',0.85*[1 1 1]);
hp(k).FaceAlpha = 0.35;
hp(k).EdgeColor = 'none';

%% Figure of nearinertial zonal averages, Figure 7

fac = 2;
clear ga
figure,
ga(1) = subplot(3,1,1);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.nearinertial_u,fac*eke_lat.nearinertial_sem_u,cc(1,:));
x = eke_lat.nearinertial_0m_MITgcm;
dx = eke_lat.nearinertial_sem_0m_MITgcm;
q = abs(targetgrid_lats)<4.33;
x(q) = NaN;dx(q) = NaN;
[h2,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(3,:));
x = eke_lat.nearinertial_0m_HYCOM;
dx = eke_lat.nearinertial_sem_0m_HYCOM;
q = abs(targetgrid_lats)<4.33;
x(q) = NaN;dx(q) = NaN;
[h3,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(5,:));
hl1 = legend(ga(1),[h1(1) h3(1) h2(1)],{'Undrogued','HYCOM (0m)','MITgcm (0m)'},'location','northwest','autoupdate','off');

ga(2) = subplot(3,1,2);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.nearinertial_d,eke_lat.nearinertial_sem_d,cc(1,:));
x = eke_lat.nearinertial_15m_MITgcm;
dx = eke_lat.nearinertial_sem_15m_MITgcm;
q = abs(targetgrid_lats)<4.33;
x(q) = NaN;dx(q) = NaN;
[h2,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(3,:));
x = eke_lat.nearinertial_15m_HYCOM;
dx = eke_lat.nearinertial_sem_15m_HYCOM;
q = abs(targetgrid_lats)<4.33;
x(q) = NaN;dx(q) = NaN;
[h3,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(5,:));
hl2 = legend(ga(2),[h1(1) h3(1) h2(1)],{'Drogued','HYCOM (15m)','MITgcm (15m)'},'location','northwest','autoupdate','off');

ga(3) = subplot(3,1,3);hold on;
x = eke_lat.nearinertial_u; y = eke_lat.nearinertial_d;
dx =  eke_lat.nearinertial_sem_u;dy =  eke_lat.nearinertial_sem_d;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h1,~] = shadyerror(ymid(ia),z,fac*z_se,cc(1,:));
x = eke_lat.nearinertial_0m_MITgcm; y = eke_lat.nearinertial_15m_MITgcm;
dx =  eke_lat.nearinertial_sem_0m_MITgcm;dy =  eke_lat.nearinertial_sem_15m_MITgcm;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
q = abs(targetgrid_lats)<4.33;
z(q) = NaN;z_se(q) = NaN;
[h2,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(3,:));
x = eke_lat.nearinertial_0m_HYCOM; y = eke_lat.nearinertial_15m_HYCOM;
dx =  eke_lat.nearinertial_sem_0m_HYCOM;dy =  eke_lat.nearinertial_sem_15m_HYCOM;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
q = abs(targetgrid_lats)<4.33;
z(q) = NaN;z_se(q) = NaN;
[h3,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(5,:));
hl2 = legend(ga(3),[h1(1) h3(1) h2(1)],{'Drifters','HYCOM','MITgcm'},'location','north','orientation','horizon','autoupdate','off');

ga(1).XLim = 60*[-1 1];
ga(2).XLim = 60*[-1 1];
ga(3).XLim = 60*[-1 1];
ga(1).YLim = [0 0.03];
ga(2).YLim = [0 0.03];
ga(3).YLim = [0.4 0.8];
for k = 1:3;ga(k).Box = 'on';end
for k = 1:2;ga(k).YLabel.String = 'm$^2$ s$^{-2}$';end
ga(3).YLabel.String = '';
ga(1).YTick = 0:0.01:0.03;
ga(2).YTick = 0:0.01:0.03;
ga(3).YTick = 0:0.1:1;

for k = 1:3;ga(k).XGrid = 'on';end
for k = 1:3;ga(k).YGrid = 'on';end

ht1 = lefttitle(ga(1),'(a) Undrogued/0m');
ht2 = lefttitle(ga(2),'(b) Drogued/15m');
ht3 = lefttitle(ga(3),'(c) 0m/(0m+15m)');

for k = 1:3
    ga(k).XTick = [-60:15:60];
    ga(k).TickDir = 'out';
end

ga(1).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(2).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(3).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};

% where nearinertial and low freq overlap
clear hp
for k = 1:2
    hp(k) = patch(ga(k),f2phi(0.5/0.9)*[-1 1 1 -1 -1]',[0 0 0.3 0.3 0]',0.85*[1 1 1]);
    hp(k).FaceAlpha = 0.35;
    hp(k).EdgeColor = 'none';
end
k = 3;
hp(k) = patch(ga(k),f2phi(0.5/0.9)*[-1 1 1 -1 -1]',[0 0 1 1 0]',0.85*[1 1 1]);
hp(k).FaceAlpha = 0.35;
hp(k).EdgeColor = 'none';

%% zonal near inertial in pacific and atlantic north, Figure 8
if 1
    fac = 2;
    clear ga
    figure,
    %North Pacific
    ga(1) = subplot(2,1,1);hold on;
    [h1,~] = shadyerror(ymid(ia),eke_lat.nearinertial_u_pac,fac*eke_lat.nearinertial_sem_u_pac,cc(1,:));
    x = eke_lat.nearinertial_0m_MITgcm_pac;
    dx = eke_lat.nearinertial_sem_0m_MITgcm_pac;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h2,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(3,:));
    x = eke_lat.nearinertial_0m_HYCOM_pac;
    dx = eke_lat.nearinertial_sem_0m_HYCOM_pac;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h3,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(5,:));
    [h4,~] = shadyerror(ymid(ia),eke_lat.nearinertial_d_pac,eke_lat.nearinertial_sem_d_pac,cc(2,:));
    x = eke_lat.nearinertial_15m_MITgcm_pac;
    dx = eke_lat.nearinertial_sem_15m_MITgcm_pac;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h5,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(4,:));
    x = eke_lat.nearinertial_15m_HYCOM_pac;
    dx = eke_lat.nearinertial_sem_15m_HYCOM_pac;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h6,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(6,:));
    hl1 = legend(ga(1),[h1(1) h4(1) h3(1) h6(1) h2(1) h5(1)],{'Undrogued','Drogued','HYCOM (0m)',...
        'HYCOM (15m)','MITgcm (0m)','MITgcm (15m)'},'location','northwest','autoupdate','off');
    h4.LineStyle = '--';
    h5.LineStyle = '--';
    h6.LineStyle = '--';
    
    ga(2) = subplot(2,1,2);hold on;
    [h1,~] = shadyerror(ymid(ia),eke_lat.nearinertial_u_atl,fac*eke_lat.nearinertial_sem_u_atl,cc(1,:));
    x = eke_lat.nearinertial_0m_MITgcm_atl;
    dx = eke_lat.nearinertial_sem_0m_MITgcm_atl;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h2,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(3,:));
    x = eke_lat.nearinertial_0m_HYCOM_atl;
    dx = eke_lat.nearinertial_sem_0m_HYCOM_atl;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h3,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(5,:));
    [h4,~] = shadyerror(ymid(ia),eke_lat.nearinertial_d_atl,eke_lat.nearinertial_sem_d_atl,cc(2,:));
    x = eke_lat.nearinertial_15m_MITgcm_atl;
    dx = eke_lat.nearinertial_sem_15m_MITgcm_atl;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h5,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(4,:));
    x = eke_lat.nearinertial_15m_HYCOM_atl;
    dx = eke_lat.nearinertial_sem_15m_HYCOM_atl;
    q = abs(targetgrid_lats)<4.33;
    x(q) = NaN;dx(q) = NaN;
    [h6,~] = shadyerror(targetgrid_lats,x,fac*dx,cc(6,:));
    h4.LineStyle = '--';
    h5.LineStyle = '--';
    h6.LineStyle = '--';
    
    ga(1).XLim = [0 60];
    ga(2).XLim = [0 60];
    ga(1).YLim = [0 0.04];
    ga(2).YLim = [0 0.04];
    
    for k = 1:2;ga(k).Box = 'on';end
    for k = 1:2;ga(k).YLabel.String = 'm$^2$ s$^{-2}$';end
    
    ga(1).YTick = 0:0.01:0.03;
    ga(2).YTick = 0:0.01:0.03;
    
    for k = 1:2;ga(k).XGrid = 'on';end
    for k = 1:2;ga(k).YGrid = 'on';end
    
    ht1 = lefttitle(ga(1),'(a) North Pacific');
    ht2 = lefttitle(ga(2),'(b) North Atlantic');
    
    for k = 1:2
        ga(k).XTick = [0:10:60];
        ga(k).TickDir = 'out';
    end
    
    ga(1).XTickLabel = {'0^\circ','10^\circN','20^\circN','30^\circN','40^\circN','50^\circN','60^\circN'};
    ga(2).XTickLabel = {'0^\circ','10^\circN','20^\circN','30^\circN','40^\circN','50^\circN','60^\circN'};
    
    % where nearinertial and low freq overlap
    clear hp
    for k = 1:2
        hp(k) = patch(ga(k),f2phi(0.5/0.9)*[-1 1 1 -1 -1]',[0 0 0.04 0.04 0]',0.85*[1 1 1]);
        hp(k).FaceAlpha = 0.35;
        hp(k).EdgeColor = 'none';
    end
    
end

%% figure of diurnal zonal averages, Figure 11

fac = 2;
clear ga
figure,
ga(1) = subplot(3,1,1);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.diurnal_u,fac*eke_lat.diurnal_sem_u,cc(1,:));
[h2,~] = shadyerror(targetgrid_lats,eke_lat.diurnal_0m_MITgcm,fac*eke_lat.diurnal_sem_0m_MITgcm,cc(3,:));
[h3,~] = shadyerror(targetgrid_lats,eke_lat.diurnal_0m_HYCOM,fac*eke_lat.diurnal_sem_0m_HYCOM,cc(5,:));
[h4,he4] = shadyerror(targetgrid_lats,eke_lat.diurnal_harmonicanalysis_0m_MITgcm,fac*eke_lat.diurnal_harmonicanalysis_sem_0m_MITgcm,cc(3,:));
[h5,he5] = shadyerror(targetgrid_lats,eke_lat.diurnal_harmonicanalysis_0m_HYCOM,fac*eke_lat.diurnal_harmonicanalysis_sem_0m_HYCOM,cc(5,:));
delete(he4);delete(he5);
h4.LineWidth = 1;h4.LineStyle = '--';
h5.LineWidth = 1;h5.LineStyle = '-.';
hl1 = legend(ga(1),[h1(1) h3(1) h2(1) h5 h4],{'Undrogued','HYCOM (0m)','MITgcm (0m)','HYCOM (0m) HA','MITgcm (0m) HA'},...
    'location','north','autoupdate','off','fontsize',8);

ga(2) = subplot(3,1,2);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.diurnal_d,fac*eke_lat.diurnal_sem_d,cc(1,:));
[h2,~] = shadyerror(targetgrid_lats,eke_lat.diurnal_15m_MITgcm,fac*eke_lat.diurnal_sem_15m_MITgcm,cc(3,:));
[h3,~] = shadyerror(targetgrid_lats,eke_lat.diurnal_15m_HYCOM,fac*eke_lat.diurnal_sem_15m_HYCOM,cc(5,:));
[h4,he4] = shadyerror(targetgrid_lats,eke_lat.diurnal_harmonicanalysis_15m_MITgcm,fac*eke_lat.diurnal_harmonicanalysis_sem_15m_MITgcm,cc(3,:));
[h5,he5] = shadyerror(targetgrid_lats,eke_lat.diurnal_harmonicanalysis_15m_HYCOM,fac*eke_lat.diurnal_harmonicanalysis_sem_15m_HYCOM,cc(5,:));
delete(he4);delete(he5);
h4.LineWidth = 1;h4.LineStyle = '--';
h5.LineWidth = 1;h5.LineStyle = '-.';
hl2 = legend(ga(2),[h1(1) h3(1) h2(1) h5 h4],{'Drogued','HYCOM (15m)','MITgcm (15m)','HYCOM (15m) HA','MITgcm (15m) HA'},...
    'location','north','autoupdate','off','fontsize',8);

ga(3) = subplot(3,1,3);hold on;
x = eke_lat.diurnal_u; y = eke_lat.diurnal_d;
dx =  eke_lat.diurnal_sem_u;dy =  eke_lat.diurnal_sem_d;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h1,~] = shadyerror(ymid(ia),z,fac*z_se,cc(1,:));
x = eke_lat.diurnal_0m_MITgcm; y = eke_lat.diurnal_15m_MITgcm;
dx =  eke_lat.diurnal_sem_0m_MITgcm;dy =  eke_lat.diurnal_sem_15m_MITgcm;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h2,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(3,:));
x = eke_lat.diurnal_0m_HYCOM; y = eke_lat.diurnal_15m_HYCOM;
dx =  eke_lat.diurnal_sem_0m_HYCOM;dy =  eke_lat.diurnal_sem_15m_HYCOM;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h3,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(5,:));
% add ratio of HA
x = eke_lat.diurnal_harmonicanalysis_0m_MITgcm; y = eke_lat.diurnal_harmonicanalysis_15m_MITgcm;
dx =  eke_lat.diurnal_harmonicanalysis_sem_0m_MITgcm;dy =  eke_lat.diurnal_harmonicanalysis_sem_15m_MITgcm;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h4,he4] = shadyerror(targetgrid_lats,z,fac*z_se,cc(3,:));
x = eke_lat.diurnal_harmonicanalysis_0m_HYCOM; y = eke_lat.diurnal_harmonicanalysis_15m_HYCOM;
dx =  eke_lat.diurnal_harmonicanalysis_sem_0m_HYCOM;dy =  eke_lat.diurnal_harmonicanalysis_sem_15m_HYCOM;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h5,he5] = shadyerror(targetgrid_lats,z,fac*z_se,cc(5,:));
delete(he4);delete(he5);
h4.LineWidth = 1;h4.LineStyle = '--';
h5.LineWidth = 1;h5.LineStyle = '-.';

hl2 = legend(ga(3),[h1(1) h3(1) h2(1) h5(1) h4(1)],{'Drifters','HYCOM','MITgcm','HYCOM HA','MITgcm HA'},...
    'location','southwest','orientation','horizon','autoupdate','off','fontsize',8);

ga(1).XLim = 60*[-1 1];
ga(2).XLim = 60*[-1 1];
ga(3).XLim = 60*[-1 1];
ga(1).YLim = [0 0.02];
ga(2).YLim = [0 0.02];
ga(3).YLim = [0.4 0.8];
for k = 1:3;ga(k).Box = 'on';end
for k = 1:2;ga(k).YLabel.String = 'm$^2$ s$^{-2}$';end
ga(3).YLabel.String = '';

for k = 1:3;ga(k).XGrid = 'on';end
for k = 1:3;ga(k).YGrid = 'on';end

ht1 = lefttitle(ga(1),'(a) Undrogued/0m');
ht2 = lefttitle(ga(2),'(b) Drogued/15m');
ht3 = lefttitle(ga(3),'(c) 0m/(0m+15m)');

for k = 1:3
    ga(k).XTick = [-60:15:60];
    ga(k).TickDir = 'out';
end

ga(1).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(2).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(3).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};

% where nearinertial and diurnal overlap 1.1 f = 0.9 and 0.9 f = 1.1
clear hp
for k = 1:2
    hp(k,1) = patch(ga(k),[f2phi(0.9/1.1)*[1 1] f2phi(1.1/0.9)*[1 1]]',[0 0.02 0.02 0]',0.85*[1 1 1]);
    hp(k,1).FaceAlpha = 0.5;
    hp(k,1).EdgeColor = 'none';
    hp(k,2) = patch(ga(k),[-f2phi(0.9/1.1)*[1 1] -f2phi(1.1/0.9)*[1 1]]',[0 0.02 0.02 0]',0.85*[1 1 1]);
    hp(k,2).FaceAlpha = 0.5;
    hp(k,2).EdgeColor = 'none';
end
k = 3;
hp(k,1) = patch(ga(k),[f2phi(0.9/1.1)*[1 1] f2phi(1.1/0.9)*[1 1]]',[0 1 1 0]',0.85*[1 1 1]);
hp(k,1).FaceAlpha = 0.5;
hp(k,1).EdgeColor = 'none';
hp(k,2) = patch(ga(k),[-f2phi(0.9/1.1)*[1 1] -f2phi(1.1/0.9)*[1 1]]',[0 1 1 0]',0.85*[1 1 1]);
hp(k,2).FaceAlpha = 0.5;
hp(k,2).EdgeColor = 'none';

%% Figure of semidiurnal zonal averages, Figure 13

fac = 2;
clear ga
figure,
ga(1) = subplot(3,1,1);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.semidiurnal_u,fac*eke_lat.semidiurnal_sem_u,cc(1,:));
[h2,~] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_0m_MITgcm,fac*eke_lat.semidiurnal_sem_0m_MITgcm,cc(3,:));
[h3,~] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_0m_HYCOM,fac*eke_lat.semidiurnal_sem_0m_HYCOM,cc(5,:));
hl1 = legend(ga(1),[h1(1) h3(1) h2(1)],{'Undrogued','HYCOM (0m)','MITgcm (0m)'},'location','northwest','autoupdate','off');

ga(2) = subplot(3,1,2);hold on;
[h1,~] = shadyerror(ymid(ia),eke_lat.semidiurnal_d,eke_lat.semidiurnal_sem_d,cc(1,:));
[h2,~] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_15m_MITgcm,fac*eke_lat.semidiurnal_sem_15m_MITgcm,cc(3,:));
[h3,~] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_15m_HYCOM,fac*eke_lat.semidiurnal_sem_15m_HYCOM,cc(5,:));
hl2 = legend(ga(2),[h1(1) h3(1) h2(1)],{'Drogued','HYCOM (15m)','MITgcm (15m)'},'location','northwest','autoupdate','off');

ga(3) = subplot(3,1,3);hold on;
x = eke_lat.semidiurnal_u; y = eke_lat.semidiurnal_d;
dx =  eke_lat.semidiurnal_sem_u;dy =  eke_lat.semidiurnal_sem_d;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;

[h1,~] = shadyerror(ymid(ia),z,fac*z_se,cc(1,:));
x = eke_lat.semidiurnal_0m_MITgcm; y = eke_lat.semidiurnal_15m_MITgcm;
dx =  eke_lat.semidiurnal_sem_0m_MITgcm;dy =  eke_lat.semidiurnal_sem_15m_MITgcm;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;

[h2,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(3,:));
x = eke_lat.semidiurnal_0m_HYCOM; y = eke_lat.semidiurnal_15m_HYCOM;
dx =  eke_lat.semidiurnal_sem_0m_HYCOM;dy =  eke_lat.semidiurnal_sem_15m_HYCOM;
z = rf(x./y);
z_se = (drf(x./y).^2.*y.^-2.*dx.^2+drf(x./y).^2.*(x.^2./y.^4).*dy.^2).^0.5;
[h3,~] = shadyerror(targetgrid_lats,z,fac*z_se,cc(5,:));
hl2 = legend(ga(3),[h1(1) h3(1) h2(1)],{'Drifters','HYCOM','MITgcm'},'location','northwest','orientation','horizon','autoupdate','off');

ga(1).XLim = 60*[-1 1];
ga(2).XLim = 60*[-1 1];
ga(3).XLim = 60*[-1 1];
ga(1).YLim = [0 0.015];
ga(2).YLim = [0 0.015];
ga(3).YLim = [0.4 0.65];
ga(3).YTick = 0.4:0.1:0.8;
for k = 1:3;ga(k).Box = 'on';end
for k = 1:2;ga(k).YLabel.String = 'm$^2$ s$^{-2}$';end
ga(3).YLabel.String = '';

for k = 1:3;ga(k).XGrid = 'on';end
for k = 1:3;ga(k).YGrid = 'on';end

ht1 = lefttitle(ga(1),'(a) Undrogued/0m');
ht2 = lefttitle(ga(2),'(b) Drogued/15m');
ht3 = lefttitle(ga(3),'(c) 0m/(0m+15m)');

for k = 1:3
    ga(k).XTick = [-60:15:60];
    ga(k).TickDir = 'out';
end

ga(1).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(2).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
ga(3).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};

% where nearinertial and semidiurnal overlap 1.1 f = 1.9: That's 59.46
% degrees, not worth it

%% Semi diurnal zonal averages, changing integration limits, Figure 14
fac = 2;
clear ga
figure,
ga(1) = subplot(4,1,1);hold on;
[h1,he1] = shadyerror(ymid(ia),eke_lat.semidiurnal_u,fac*eke_lat.semidiurnal_sem_u,cc(1,:));
[h2,he2] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_0m_MITgcm,fac*eke_lat.semidiurnal_sem_0m_MITgcm,cc(3,:));
[h3,he3] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_0m_HYCOM,fac*eke_lat.semidiurnal_sem_0m_HYCOM,cc(5,:));
[h4,he4] = shadyerror(ymid(ia),eke_lat.semidiurnal_d,fac*eke_lat.semidiurnal_sem_d,cc(2,:));
[h5,he5] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_15m_MITgcm,fac*eke_lat.semidiurnal_sem_15m_MITgcm,cc(4,:));
[h6,he6] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_15m_HYCOM,fac*eke_lat.semidiurnal_sem_15m_HYCOM,cc(6,:));
delete([he1 he2 he3 he4 he5 he6])
h4.LineStyle = '--';
h5.LineStyle = '--';
h6.LineStyle = '--';
hl1 = legend(ga(1),[h1(1) h3(1) h2(1)],{'Undrogued','HYCOM (0m)','MITgcm (0m)'},'location','northwest','autoupdate','off');

ga(2) = subplot(4,1,2);hold on;
[h1,he1] = shadyerror(ymid(ia),eke_lat.semidiurnal_wide_u,fac*eke_lat.semidiurnal_wide_sem_u,cc(1,:));
[h2,he2] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wide_0m_MITgcm,fac*eke_lat.semidiurnal_wide_sem_0m_MITgcm,cc(3,:));
[h3,he3] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wide_0m_HYCOM,fac*eke_lat.semidiurnal_wide_sem_0m_HYCOM,cc(5,:));
[h4,he4] = shadyerror(ymid(ia),eke_lat.semidiurnal_wide_d,fac*eke_lat.semidiurnal_wide_sem_d,cc(2,:));
[h5,he5] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wide_15m_MITgcm,fac*eke_lat.semidiurnal_wide_sem_15m_MITgcm,cc(4,:));
[h6,he6] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wide_15m_HYCOM,fac*eke_lat.semidiurnal_wide_sem_15m_HYCOM,cc(6,:));
delete([he1 he2 he3 he4 he5 he6])
h4.LineStyle = '--';
h5.LineStyle = '--';
h6.LineStyle = '--';
hl1 = legend(ga(2),[h4(1) h6(1) h5(1)],{'Drogued','HYCOM (15m)','MITgcm (15m)'},'location','northwest','autoupdate','off');

ga(3) = subplot(4,1,3);hold on;
[h1,he1] = shadyerror(ymid(ia),eke_lat.semidiurnal_wider_u,fac*eke_lat.semidiurnal_wider_sem_u,cc(1,:));
[h2,he2] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wider_0m_MITgcm,fac*eke_lat.semidiurnal_wider_sem_0m_MITgcm,cc(3,:));
[h3,he3] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wider_0m_HYCOM,fac*eke_lat.semidiurnal_wider_sem_0m_HYCOM,cc(5,:));
[h4,he4] = shadyerror(ymid(ia),eke_lat.semidiurnal_wider_d,fac*eke_lat.semidiurnal_wider_sem_d,cc(2,:));
[h5,he5] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wider_15m_MITgcm,fac*eke_lat.semidiurnal_wider_sem_15m_MITgcm,cc(4,:));
[h6,he6] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_wider_15m_HYCOM,fac*eke_lat.semidiurnal_wider_sem_15m_HYCOM,cc(6,:));
delete([he1 he2 he3 he4 he5 he6])
h4.LineStyle = '--';
h5.LineStyle = '--';
h6.LineStyle = '--';

ga(4) = subplot(4,1,4);hold on;
[h1,he1] = shadyerror(ymid(ia),eke_lat.semidiurnal_widest_u,fac*eke_lat.semidiurnal_widest_sem_u,cc(1,:));
[h2,he2] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_widest_0m_MITgcm,fac*eke_lat.semidiurnal_widest_sem_0m_MITgcm,cc(3,:));
[h3,he3] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_widest_0m_HYCOM,fac*eke_lat.semidiurnal_widest_sem_0m_HYCOM,cc(5,:));
[h4,he4] = shadyerror(ymid(ia),eke_lat.semidiurnal_widest_d,fac*eke_lat.semidiurnal_widest_sem_d,cc(2,:));
[h5,he5] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_widest_15m_MITgcm,fac*eke_lat.semidiurnal_widest_sem_15m_MITgcm,cc(4,:));
[h6,he6] = shadyerror(targetgrid_lats,eke_lat.semidiurnal_widest_15m_HYCOM,fac*eke_lat.semidiurnal_widest_sem_15m_HYCOM,cc(6,:));
delete([he1 he2 he3 he4 he5 he6])
h4.LineStyle = '--';
h5.LineStyle = '--';
h6.LineStyle = '--';

for k = 1:4
    ga(k).XLim = 60*[-1 1];
    ga(k).YLim = [0 0.017];
    ga(k).YTick = [0:0.005:0.017];
end

for k = 1:4;ga(k).Box = 'on';end

for k = 1:4;ga(k).YLabel.String = 'm$^2$ s$^{-2}$';end

for k = 1:4;ga(k).XGrid = 'on';end
for k = 1:4;ga(k).YGrid = 'on';end

ht1 = lefttitle(ga(1),'(a) 1.9 - 2.1 cpd');
ht2 = lefttitle(ga(2),'(b) 1.8 - 2.2 cpd');
ht3 = lefttitle(ga(3),'(c) 1.7 - 2.3 cpd');
ht4 = lefttitle(ga(4),'(d) 1.6 - 2.4 cpd');

for k = 1:4
    ga(k).XTick = [-60:15:60];
    ga(k).TickDir = 'out';
end

for k = 1:4
    ga(k).XTickLabel = {'60^\circS','45^\circS','30^\circS','15^\circS','0^\circ','15^\circN','30^\circN','45^\circN','60^\circN'};
end

% latitudes where the limits of integrations overlap with inertial
k = 3;
hp(k,1) = patch(ga(k),[f2phi(1.7/1.1)*[1 1] f2phi(2.3/0.9)*[1 1]]',[0 0.02 0.02 0]',0.85*[1 1 1]);
hp(k,1).FaceAlpha = 0.35;
hp(k,1).EdgeColor = 'none';
hp(k,2) = patch(ga(k),[-f2phi(1.7/1.1)*[1 1] -f2phi(2.3/0.9)*[1 1]]',[0 0.02 0.02 0]',0.85*[1 1 1]);
hp(k,2).FaceAlpha = 0.35;
hp(k,2).EdgeColor = 'none';

k = 4;
hp(k,1) = patch(ga(k),[f2phi(1.6/1.1)*[1 1] f2phi(2.4/0.9)*[1 1]]',[0 0.02 0.02 0]',0.85*[1 1 1]);
hp(k,1).FaceAlpha = 0.35;
hp(k,1).EdgeColor = 'none';
hp(k,2) = patch(ga(k),[-f2phi(1.6/1.1)*[1 1] -f2phi(2.4/0.9)*[1 1]]',[0 0.02 0.02 0]',0.85*[1 1 1]);
hp(k,2).FaceAlpha = 0.35;
hp(k,2).EdgeColor = 'none';

%% Figure 2 calculations: 2D (Elipot) spectra for drifters, HYCOM, and MITgcm

% load frequency-latitude 2D spectra from drifter data
dat1 = load([path_to_repo 'DRIFTERS_RESULTS_AND_README/globalspectra_104.mat']);

% calculate zonal averages from models

load([path_to_repo 'HYCOM_ANALYSISCODE_RESULTS_AND_README/HYCOM_binaverages_onedegreegrid_fullspectra.mat']);
load([path_to_repo 'MITgcm_ANALYSISCODE_RESULTS_AND_README/binavg_MITgcm_fullspectra_onto_onedeg_grid.mat']);

timelength = 1440; % number of hours in a 60-day window
timeinterval=  1; % number of hours between samples of the model
omegavector_rotary_model = (2*pi/(timelength*timeinterval*3600) )*[1-timelength/2:timelength/2];
omegavector_rotary_cpd_model = omegavector_rotary_model*86400/(2*pi);

zonalaverage_0m_HYCOM = 0*ones(120,1440);
zonalaverage_15m_HYCOM = 0*ones(120,1440);
zonalaverage_0m_MITgcm = 0*ones(120,1440);
zonalaverage_15m_MITgcm = 0*ones(120,1440);

% We use the following variable to keep track of the number of samples per
%  latitude, which is needed to compute a global area-weighted spectra:
numbersamples_perlatitude = 0*ones(120,1); 

for m=1:120
    
  dummy_0m_HYCOM = reshape(HYCOM_0m_fullspectra_binavg(m,:,:),360,1440);
  dummy_15m_HYCOM = reshape(HYCOM_15m_fullspectra_binavg(m,:,:),360,1440);
  dummy_0m_MITgcm = reshape(MITgcm_0m_fullspectra_binavg(m,:,:),360,1440);
  dummy_15m_MITgcm = reshape(MITgcm_15m_fullspectra_binavg(m,:,:),360,1440);
  % find NaNs at a particular frequency (randomly picked to be the 5th index):
  list_for_finding_nans = dummy_0m_HYCOM(:,5)+dummy_15m_HYCOM(:,5)+dummy_0m_MITgcm(:,5)+dummy_15m_MITgcm(:,5);
  bad_indices = find(isnan(list_for_finding_nans));
  numbersamples_perlatitude(m) = 360-length(bad_indices);
  dummy_0m_HYCOM(bad_indices,:) = nan;
  dummy_15m_HYCOM(bad_indices,:) = nan;
  dummy_0m_MITgcm(bad_indices,:) = nan;
  dummy_15m_MITgcm(bad_indices,:) = nan;
  zonalaverage_0m_HYCOM(m,:) = nanmean(dummy_0m_HYCOM);
  zonalaverage_15m_HYCOM(m,:) = nanmean(dummy_15m_HYCOM);
  zonalaverage_0m_MITgcm(m,:) = nanmean(dummy_0m_MITgcm);
  zonalaverage_15m_MITgcm(m,:) = nanmean(dummy_15m_MITgcm);

  clear bad_indices dummy_0m_HYCOM dummy_0m_MITgcm dummy_15m_HYCOM dummy_15m_MITgcm list_for_finding_nans
  disp(['Completed latitude number ',num2str(m),' of 120']);
  
end

%% Figure 2, plotting

clear g
figure, 
g(1) = subplot(3,2,1);hold on
jpcolor(dat1.xmid/2/pi,dat1.ymid,log10(dat1.mspp_u));
jpcolor(-dat1.xmid/2/pi,dat1.ymid,log10(dat1.msnn_u));
set(gca,'ydir','normal');
axis tight
ytick([-60:20:60]),
xtick([-12:1:12]);
ylim([-61 61]);
xlim([-1 1]*5);
caxis([-6 1]);
colormap lansey
title(g(1),'(a) Undrogued drifters');

g(2) = subplot(3,2,2);hold on
jpcolor(dat1.xmid/2/pi,dat1.ymid,log10(dat1.mspp_d));
jpcolor(-dat1.xmid/2/pi,dat1.ymid,log10(dat1.msnn_d));
set(gca,'ydir','normal');
axis tight
ytick([-60:20:60]),
xtick([-12:1:12]);
ylim([-61 61])
xlim([-1 1]*5)
caxis([-6 1]);
colormap lansey
title(g(2),'(b) Drogued drifters');

g(3) = subplot(3,2,3);hold on
jpcolor(omegavector_rotary_cpd_model,dat1.ymid,log10(zonalaverage_0m_HYCOM));
set(gca,'ydir','normal');
axis tight
ytick([-60:20:60]),
xtick([-12:1:12]);
ylim([-61 61]);
xlim([-1 1]*5);
caxis([-6 1]);
colormap lansey
title(g(3),'(c) HYCOM 0 m');

g(4) = subplot(3,2,4);hold on
jpcolor(omegavector_rotary_cpd_model,dat1.ymid,log10(zonalaverage_15m_HYCOM));
set(gca,'ydir','normal');
axis tight
ytick([-60:20:60]),
xtick([-12:1:12]);
ylim([-61 61]);
xlim([-1 1]*5);
caxis([-6 1]);
colormap lansey
title(g(4),'(d) HYCOM 15 m');

g(5) = subplot(3,2,5);hold on
jpcolor(omegavector_rotary_cpd_model,dat1.ymid,log10(zonalaverage_0m_MITgcm));
set(gca,'ydir','normal');
axis tight
ytick([-60:20:60]),
xtick([-12:1:12]);
ylim([-61 61]);
xlim([-1 1]*5);
caxis([-6 1]);
colormap lansey
title(g(5),'(e) MITgcm 0 m');

g(6) = subplot(3,2,6);hold on
jpcolor(omegavector_rotary_cpd_model,dat1.ymid,log10(zonalaverage_15m_MITgcm));
set(gca,'ydir','normal');
axis tight
ytick([-60:20:60]),
xtick([-12:1:12]);
ylim([-61 61]);
xlim([-1 1]*5);
caxis([-6 1]);
colormap lansey
title(g(6),'(f) MITgcm 15 m');

packfig(3,2)

for k = [1 3 5]
    g(k).YTick = [-60:20:60];
    g(k).YTickLabel = {'60^\circS','40^\circS','20^\circS','0^\circ','20^\circN','40^\circN','60^\circN'};
end

g(6).XTick = [-4:1:5];
for k = [1 3 5]
    g(k).YLabel.String = '';
end
for k = [5 6]
    g(k).XLabel.String = 'Frequency (cpd)';
end

p1 = g(1).Position;
g(1).Position = p1 + [0 0.015*2 0 0];
p2 = g(2).Position;
g(2).Position = p2 + [0 0.015*2 0 0];

p5 = g(5).Position;
g(5).Position = p5 + [0 -0.015*2 0 0];
p6 = g(6).Position;
g(6).Position = p6 + [0 -0.015*2 0 0];

hc6 = colorbar(g(6),'location','EastOutside');
dum = hc6.Position;
hc6.Position = dum + [0.08 0 0 0];
%set(get(hc6,'xlabel'),'string','log_{10} m^2 s^{-2} cpd^{-1}');
hc6.TickLabels = {'10^{-6}','10^{-5}','10^{-4}','10^{-3}','10^{-2}','10^{-1}','10^{0}','10^{1}'};

ht = text(g(4),6.5, -70,'m$^2$ s$^{-2}$ cpd$^{-1}$','rotation',90,'fontsize',14);

colormap(cmocean('thermal'));

if 0 % optional: draw frequency integration limits
    dum = linspace(-60,60,200);
    ff = phi2f(dum);
    for k = 1:6
        plot(g(k),ff(:)*[0.9 1.1],dum,'k-',-ff(:)*[0.9 1.1],dum,'k-');
    end
    
    for k = 1:6
         plot(g(k),0.9*[1 1],[-60 60],'k-');
         plot(g(k),1.1*[1 1],[-60 60],'k-');
         plot(g(k),-0.9*[1 1],[-60 60],'k-');
         plot(g(k),-1.1*[1 1],[-60 60],'k-');
         plot(g(k),1.9*[1 1],[-60 60],'k-');
         plot(g(k),2.1*[1 1],[-60 60],'k-');        
         plot(g(k),-1.9*[1 1],[-60 60],'k-');
         plot(g(k),-2.1*[1 1],[-60 60],'k-');    
        plot(g(k),0.5*[1 1],[-60 60],'k-');    
        plot(g(k),-0.5*[1 1],[-60 60],'k-');        
    end
 
end

%%
