function c = mycolormap(varargin)
% COLORMAPS - returns a polarity color map
%
%       MYCOLORPMAP returns a colormap from navy blue to magenta via white
%
%       MYCOLORPMAP(N) or MYCOLORPMAP(N,1) returns a colormap with N discrete steps 
%       from navy blue to magenta via white
%
%       MYCOLORPMAP(N,S) with S == 2 returns a colormap with N discrete steps 
%       from blue to cyan then yellow to red
%  
%       MYCOLORPMAP(N,S) with S == 3 returns a colormap with N discrete steps 
%       like the jet colormap but with white instead of green (dark red, yellow, green, cyan, blue, dark blue)
%
%       MYCOLORPMAP(N,S) with S == 4 returns a colormap with N discrete steps 
%       from blue to magenta via white
%  
%       MYCOLORPMAP(N,S) with S == 5 returns a colormap with N discrete steps 
%       from red, yellow, green, cyan, blue
%  
%       MYCOLORPMAP(N,S) with S ~= 3, 2, or 1 returns a colormap with N discrete steps 
%       from navy blue to cyan, then yellow to red
%  
%       Note that an even number N will return a balanced colormap
%  
% Shane Elipot, 2009  

if isempty(varargin)
  n = 22;
  option = 1;
elseif nargin == 1
  n = varargin{1};
  option = 1;
  if rem(n,2) ~= 0
    disp('the colormap will not be balanced');
  end
elseif nargin == 2
  n = varargin{1};
  option = varargin{2};
  if rem(n,2) ~= 0
    disp('the colormap will not be balanced');
  end
end

n = n - 2;

if option == 1
  dr = [1 0 1];
  w1 = [1 1 1]; 
  nb = [0 0 0.5]; 
  w2 = [1 1 1];
elseif option == 4
  dr = [1 0 1];
  w1 = [1 1 1]; 
  nb = [0 0 1]; 
  w2 = [1 1 1];
elseif option == 3
  dr = [1 0 0;
        0.5 0 0];
  w1 = [1 1 1;
        1 1 0.5]; 
  nb = [0 0 0.5;
        0 0 1];
  w2 = [0.5 1 1;
        1 1 1];
elseif option == 2
  dr = [1 0 0];
  w1 = [1 1 0.5]; 
  nb = [0 0 1];
  w2 = [0.5 1 1];
else
  dr = [1 0 0];
  w1 = [1 1 0.5]; 
  nb = [0 0 0.5];
  w2 = [0.5 1 1];
end

n1 = floor(n/2);
n2 = n-n1;


if option == 3
  c1 = interp1([0 ; 0.25 ; 0.75 ; 1],[nb ; w2],[0:1/n1:1]);
  c2 = interp1([0 ; 0.25 ; 0.75 ; 1],[w1 ; dr],[0:1/n2:1]);
else
  c1 = interp1([0 ; 1],[nb ; w2],[0:1/n1:1]);
  c2 = interp1([0 ; 1],[w1 ; dr],[0:1/n2:1]);  
end

c = [c1 ; c2];
